==> angr-9.2.118.tar.gz: angr-9.2.118/angr/procedures/definitions/win32_licenseprotection.py <==
# pylint:disable=line-too-long
from __future__ import annotations
import logging
from collections import OrderedDict

from ...sim_type import (SimTypeFunction,
    SimTypeShort,
    SimTypeInt,
    SimTypeLong,
    SimTypeLongLong,
    SimTypeDouble,
    SimTypeFloat,
    SimTypePointer,
    SimTypeChar,
    SimStruct,
    SimTypeArray,
    SimTypeBottom,
    SimUnion,
    SimTypeBool,
    SimTypeRef,
)
from ...calling_conventions import SimCCStdcall, SimCCMicrosoftAMD64
from .. import SIM_PROCEDURES as P
from . import SimLibrary


_l = logging.getLogger(name=__name__)


lib = SimLibrary()
lib.type_collection_names = ["win32"]
lib.set_default_cc("X86", SimCCStdcall)
lib.set_default_cc("AMD64", SimCCMicrosoftAMD64)
lib.set_library_names("licenseprotection.dll")
prototypes = \
    {
        #
        'RegisterLicenseKeyWithExpiration': SimTypeFunction([SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="LicenseProtectionStatus"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["licenseKey", "validityInDays", "status"]),
        #
        'ValidateLicenseKeyProtection': SimTypeFunction([SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypePointer(SimTypeRef("FILETIME", SimStruct), offset=0), SimTypePointer(SimTypeRef("FILETIME", SimStruct), offset=0), SimTypePointer(SimTypeInt(signed=False, label="LicenseProtectionStatus"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["licenseKey", "notValidBefore", "notValidAfter", "status"]),
    }

lib.set_prototypes(prototypes)

==> angr-9.2.121.tar.gz: angr-9.2.121/angr/procedures/definitions/win32_licenseprotection.py <==
# pylint:disable=line-too-long
from __future__ import annotations
import logging
from collections import OrderedDict

from angr.sim_type import SimTypeFunction, SimTypeShort, SimTypeInt, SimTypeLong, SimTypeLongLong, SimTypeDouble, SimTypeFloat, SimTypePointer, SimTypeChar, SimStruct, SimTypeArray, SimTypeBottom, SimUnion, SimTypeBool, SimTypeRef
from angr.calling_conventions import SimCCStdcall, SimCCMicrosoftAMD64
from angr.procedures import SIM_PROCEDURES as P
from . import SimLibrary


_l = logging.getLogger(name=__name__)


lib = SimLibrary()
lib.type_collection_names = ["win32"]
lib.set_default_cc("X86", SimCCStdcall)
lib.set_default_cc("AMD64", SimCCMicrosoftAMD64)
lib.set_library_names("licenseprotection.dll")
prototypes = \
    {
        #
        'RegisterLicenseKeyWithExpiration': SimTypeFunction([SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypeInt(signed=False, label="UInt32"), SimTypePointer(SimTypeInt(signed=False, label="LicenseProtectionStatus"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["licenseKey", "validityInDays", "status"]),
        #
        'ValidateLicenseKeyProtection': SimTypeFunction([SimTypePointer(SimTypeChar(label="Char"), offset=0), SimTypePointer(SimTypeRef("FILETIME", SimStruct), offset=0), SimTypePointer(SimTypeRef("FILETIME", SimStruct), offset=0), SimTypePointer(SimTypeInt(signed=False, label="LicenseProtectionStatus"), offset=0)], SimTypeInt(signed=True, label="Int32"), arg_names=["licenseKey", "notValidBefore", "notValidAfter", "status"]),
    }

lib.set_prototypes(prototypes)
